## Typing stubs for braintree

This is a [PEP 561](https://peps.python.org/pep-0561/)
type stub package for the [`braintree`](https://github.com/braintree/braintree_python) package.
It can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
[Pyre](https://pyre-check.org/),
PyCharm, etc. to check code that uses `braintree`. This version of
`types-braintree` aims to provide accurate annotations for
`braintree==4.34.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/braintree`](https://github.com/python/typeshed/tree/main/stubs/braintree)
directory.

This package was tested with
mypy 1.15.0,
pyright 1.1.400,
and pytype 2024.10.11.
It was generated from typeshed commit
[`ebf4d17c8d1ba2be348c51be39faec4d0303d8fa`](https://github.com/python/typeshed/commit/ebf4d17c8d1ba2be348c51be39faec4d0303d8fa).